@@ -167,7 +167,7 @@ use std::time::{Duration, Instant, SystemTime};
 use log::{debug, error, warn};
 
 pub const SERVER_ID: &str = "yedb-altt-rs";
-pub const VERSION: &str = "0.0.4";
+pub const VERSION: &str = "0.0.5";
 pub const ENGINE_VERSION: u8 = 1;
 
 pub const DEFAULT_CACHE_SIZE: usize = 1000;
@@ -954,7 +954,7 @@ impl Database {
         );
         let engine = get_engine!(self);
         let key = fmt_key(key);
-        if key.starts_with(".trash/") || key == "trash" {
+        if key.starts_with(".trash/") || key == ".trash" {
             return Err(Error::new(
                 ErrorKind::KeyNotFound,
                 "Use purge to remove trashed items",
@@ -989,16 +989,16 @@ impl Database {
         if !dir_only && key.len() > 0 {
             let key_file =
                 self.key_path.clone() + "/" + key.as_str() + engine.get_suffix().as_str();
-            if self.auto_flush && !no_flush {
-                match fs::File::create(&key_file) {
-                    Ok(mut fh) => {
-                        unwrap_io!(fh.flush());
-                        unwrap_io!(fh.sync_all());
-                    }
-                    Err(ref e) if e.kind() == io::ErrorKind::NotFound => {}
-                    Err(e) => return Err(Error::new(ErrorKind::IOError, e)),
-                }
-            }
+            //if self.auto_flush && !no_flush {
+            //match fs::File::create(&key_file) {
+            //Ok(mut fh) => {
+            //unwrap_io!(fh.flush());
+            //unwrap_io!(fh.sync_all());
+            //}
+            //Err(ref e) if e.kind() == io::ErrorKind::NotFound => {}
+            //Err(e) => return Err(Error::new(ErrorKind::IOError, e)),
+            //}
+            //}
             let trashed = format!(
                 "{}/{}.{}{}",
                 self.trash_path.clone(),
@@ -1607,6 +1607,7 @@ impl Database {
                 }
             }
             Err(ref e) if e.kind() == io::ErrorKind::NotFound => {}
+            Err(ref e) if e.kind() == io::ErrorKind::InvalidInput => {}
             Err(e) => return Err(Error::new(ErrorKind::IOError, e)),
         };
 
